<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Util\Sidebar\Link;
use EventPortal\Tests\TestCase;

class LinkTest extends TestCase
{
    /** @test **/
    public function make_with_name()
    {
        $link = Link::make('primary');

        $this->assertEquals('primary', $link->name);
    }

    /** @test **/
    public function make_with_null_name()
    {
        $link = Link::make();

        $this->assertNull($link->name);
    }

    /** @test **/
    public function make_with_icon()
    {
        $link = Link::make('delegates')->icon('people-icon');

        $this->assertEquals('people-icon', $link->icon);
    }

    /** @test **/
    public function make_with_route()
    {
        $link = Link::make('delegates')->route('admin.thing.index');

        $this->assertEquals('admin.thing.index', $link->route);
        $this->assertNull($link->routeParams);
    }

    /** @test **/
    public function make_with_route_and_params()
    {
        $link = Link::make('delegates')
            ->route('admin.thing.index', ['event' => 1]);

        $this->assertEquals('admin.thing.index', $link->route);
        $this->assertEquals(['event' => 1], $link->routeParams);
    }

    /** @test **/
    public function make_with_permission()
    {
        $link = Link::make('delegates')->permission('can.something');

        $this->assertEquals('can.something', $link->permission);
    }

    /** @test **/
    public function can_add_children()
    {
        $link = Link::make('primary')
            ->addChildren([
                Link::make('waffle'),
            ]);

        $expected = [
            [
                'name' => 'waffle',
                'route' => null,
                'routeParams' => null,
                'icon' => null,
                'children' => null,
            ],
        ];

        $this->assertEquals($expected, $link->children);
    }

    /** @test **/
    public function can_render()
    {
        $link = Link::make('Delegates')
            ->icon('user-plus')
            ->addChildren([
                Link::make('View delegates')
                    ->route('admin.delegate.index')
                    ->permission('delegate.show'),
            ])
            ->permission('delegate.manage')
            ->route('admin.delegate.index', ['event' => 1]);

        $expected = [
            'name' => 'Delegates',
            'route' => 'admin.delegate.index',
            'routeParams' => ['event' => 1],
            'icon' => 'user-plus',
            'children' => [
                [
                    'name' => 'View delegates',
                    'route' => 'admin.delegate.index',
                    'routeParams' => null,
                    'icon' => null,
                    'children' => null,
                ],
            ],
        ];

        $this->assertEquals($expected, $link->render());
    }
}
